@@ -102,6 +102,7 @@ def get_instance_info(instances, class_instance):
     """get and print instance info to the screen"""
     # collect info
     state_code = 0
+    matching_hint = False
     for instance in instances:
         matching_hint = False
         instance_id = instance['Instances'][0]['InstanceId']
@@ -147,6 +148,8 @@ def get_instance_info(instances, class_instance):
             if class_instance.hint:
                 if matching_hint:
                     sys.stdout.write(description + '\n')
+                else:
+                    print("no matching instances")
             else:
                 sys.stdout.write(description + '\n')
         else:
@@ -154,6 +157,8 @@ def get_instance_info(instances, class_instance):
                 if matching_hint:
                     print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
                     print("-------")
+                else:
+                    print(cs("no instances found.", "yellow"))
             else:
                 print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
                 print("-------")
